@@ -50,6 +50,8 @@ Updates from Wikipedia:
 
 =item version 0.72, published on May 1, 2006
 
+=item version 0.74, published on May 15, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -133,6 +135,8 @@ Aspen_Stevens
 Audrey_Hollander
 Aurora_Snow
 Austin_O_Riley
+Austin_Kincaid
+Autum_Jade
 Ava_Devine
 Ava_Nova
 Ava_Ramone
@@ -147,6 +151,7 @@ Bambi_Blaze
 Bambi_Woods
 Bamboo
 Barbara_Dare
+Barbara_Summer
 Barbie_Griffin
 Belladonna
 Betty_G
@@ -157,6 +162,7 @@ Bianca_Trump
 Bibi_Fox
 Bianca_Pureheart
 Bionca
+Blair_Segal
 Blondie_Bee
 Bobbi_Billard
 Bobbi_Eden
@@ -297,6 +303,7 @@ Felix_Vicious
 Flame
 Flick_Shagwell
 Flower_Tucci
+Friday
 Fujiko_Kano
 Gauge
 Genevieve_Elise_Silva
@@ -313,6 +320,7 @@ Gina_Ryder
 Ginger_Lynn
 Gloria_Guida
 Gloria_Leonard
+Gwen_Summers
 Hannah_Harper
 Haven
 Heather_Hunter
@@ -324,12 +332,12 @@ Haley_Paige
 Honey_Wilder
 Houston
 Hyapatia_Lee
+Ice_La_Fox
 Inari_Vachs
 India
 Isis_Nile
 JR_Carrington
 Jackie_Ashe
-Jackie_Hincapie
 Jackie_Moore
 Jacqueline_Lorians
 Jada_Fire
@@ -356,6 +364,7 @@ Jeanna_Fine
 Jelena_Jensen
 Jenna_Haze
 Jenna_Jameson
+Jennifer_Andersson
 Jennifer_Noxt
 Jenteal
 Jesse_Jane
@@ -390,6 +399,7 @@ Karen_Lancaume
 Karin_Schubert
 Karina_Kay
 Kascha_Papillon
+Katrina_Kraven
 Katalyn_Cica
 Kate_Frost
 Kathy_Willets
@@ -402,10 +412,12 @@ Katja_Love
 Katsumi
 Kawashima_Azumi
 Kay_Parker
+Kayla_Marie
 Kaylani_Lei
 Kaylynn
 Keiko_Nakazawa
 Kelle_Marie
+Kelly_Erikson
 Kelly_Kline
 Kelly_Kroft
 Kelly_Nichols
@@ -423,11 +435,13 @@ Kim_Angeli
 Kim_Chambers
 Kinky_Celine
 Kinzie_Kenner
+Kira_Kener
 Kitten_Natividad
 Kitty_Marie
 Kitty_Yung
 Kobe_Tai
 Kristara_Barrington
+Krystal_de_Boor
 Krysti_Lynn
 Kristi_Myst
 Krystal_Steal
@@ -449,7 +463,9 @@ Leanna_Heart
 Leena
 Lene_Hefner
 Leslie_Bovee
+Lexie_Marie
 Lily_Thai
+Lilian_Lee
 Lillian_Tiger
 Linda_Lovelace
 Linda_Lust
@@ -461,6 +477,7 @@ Lisa_Ann
 Lisa_Loring
 Lisa_Sparxxx
 Little_Oral_Annie
+Liz_Harvey
 Liza_Harper
 Logan_LaBrent
 Lois_Ayres
@@ -505,6 +522,7 @@ Michelle_Thorne
 Michelle_Wild
 Micka_French
 Mika_Tan
+Mike_Mulhall
 Miko_Lee
 Mimi_Miyagi
 Mindy_Vega
@@ -523,12 +541,15 @@ Monica_Sweet
 Monica_Sweetheart
 Monique_Alexander
 Monique_DeMoan
+Mya_Mason
+Mysti_May
 Nadia_Nyce
 Naomi
 Nautica_Thorn
 Naughty_Alysha
 Nena_Cherry
 Nichola_Holt
+Nicole_Sheridan
 Nici_Sterling
 Nikita_Denise
 Nikki_Anderson
@@ -542,6 +563,7 @@ Nikki_Hunter
 Nikki_Knights
 Nikki_Nova
 Nikki_Park
+Nikki_Rider
 Nikki_Tyler
 Nina_DePonca
 Nina_Hartley
@@ -558,14 +580,17 @@ Paizley_Adams
 Pamela_Anderson
 Pandora_Dreams
 Pandora_Peaks
+Paris_Hilton
 Penelope_Black_Diamond
 Penny_Flame
 Penny_Porsche
 Persia
+Phoenix_Ray
 Pixie
 PJ_Sparxx
 Poppy_Morgan
 Porsche_Lynn
+Priya_Rai
 Rachel_Aziani
 Rachel_Rotten
 Rachel_Ryan
@@ -579,12 +604,14 @@ Rebecca_Cummings
 Rebecca_Lord
 Reika
 Renee_Pornero
+Rikki_Anderson
 Riley_Mason
 Rita_Faltoyano
 Rocki_Roads
 Roxanne_Hall
 Roxy_Jezel
 Roxy_Rush
+Sabina_Black
 Sabrina_Johnson
 Sabrine_Maui
 Sakura_Sena
@@ -596,7 +623,10 @@ Sandra_Shine
 Sandy
 Saphire_Rae
 Sara_Jay
+Sarah_Blue
 Sarah_Louise_Young
+Sarah_Twain
+Sascha
 Sativa_Rose
 Savanna_Samson
 Savannah
@@ -624,6 +654,8 @@ Simony_Diamond
 Sindee_Coxx
 Sin_Eye
 Sky_Lopez
+Skylar_Knight
+Sonia_Jensen
 Sophia_Ferrari
 Sophia_Rossi
 Sophie_Evans
@@ -679,10 +711,13 @@ Tiffany_Hopkins
 Tiffany_May
 Tiffany_Million
 Tiffany_Mynx
+Tiffany_Rayne
 Tiffany_Teen
 Tiffany_Towers
 Tiffany_Walker
 Timea_Vagvolgyi
+Tina_Cheri
+Tina_Fine
 Tove_Jensen
 Tori_DeLuca
 Tori_Welles
@@ -738,6 +773,7 @@ Andrea_Nobili
 Barry_Wood
 Ben_Dover
 Ben_English
+Ben_Hardy
 Benjamin_Brat
 Big_Herc
 Biggz
@@ -811,7 +847,6 @@ Frank_Major
 Frank_Shaft
 Frank_Towers
 Frankie_Versace
-Gauge
 Gene_Ross
 George_Payne
 George_Uhl
@@ -909,7 +944,7 @@ Mike_Horner
 Mike_Ranger
 Mickey_G
 Miles_Malone
-MrLothar
+Mr_Lothar
 Mr_Marcus
 Mr_Pete
 Nacho_Vidal
@@ -957,6 +992,7 @@ Rocco_Siffredi
 Rod_Fontana
 Ron_Jeremy
 Ryan_Idol
+Richard_Pacheco
 Samson_Biceps
 Sam_Strong
 Scott_Lyons
